package mk.tmarkovski.android.glasnik;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.text.format.DateFormat;
import android.text.format.DateUtils;
import android.util.Log;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 26.2.12
 * Time: 19:39
 * To change this template use File | Settings | File Templates.
 */
public class Utils implements AppConstants {
    public static Bitmap scaleBitmap(Bitmap bitmap) {
        int height = bitmap.getHeight();
        int width = bitmap.getWidth();
        if (height <= WIDGET_IMAGE_MAX_SIZE && width <= WIDGET_IMAGE_MAX_SIZE)
            return bitmap;

        float factor = (height > width) ? height / WIDGET_IMAGE_MAX_SIZE : width / WIDGET_IMAGE_MAX_SIZE;
        int w = (int) Math.round(width / factor);
        int h = (int) Math.round(height / factor);

        Matrix matrix = new Matrix();
        matrix.postScale(1 / factor, 1 / factor);

        Bitmap b = Bitmap.createBitmap(bitmap, 0, 0, width, height, matrix, true);
        bitmap.recycle();
        return b;
    }

    public static String getWidgetDateFormat(Context context, long date) {
        String[] days = {"понеделник", "втроник", "среда", "четврток", "петок", "сабота", "недела"};
        String[] months = {"јан", "фев", "мар", "апр", "мај", "јун", "јул", "авг", "сеп", "окт", "ное", "дек"};
        //long date = PreferenceManager.getDefaultSharedPreferences(context).getLong("updated", new Date().getTime());
        //long today = new Date().getTime();
        //long diff = (today - date) / (1000 / 60 / 60 / 24);
        String formattedDate = "";
        if (DateUtils.isToday(date))
            formattedDate += "денес во " + DateFormat.format("kk:mm", date);
        else if (isYesterday(date))
            formattedDate += "вчера во " + DateFormat.format("kk:mm", date);
        else
            formattedDate += String.format("%s %s, %s",
                    new Date(date).getDate(),
                    months[new Date(date).getMonth()],
                    DateFormat.format("kk:mm", date));

        return formattedDate;
    }

    private static boolean isYesterday(long date) {
        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(date);

        Calendar cal1 = Calendar.getInstance();
        cal1.setTimeInMillis(new Date().getTime());
        cal1.add(Calendar.DATE, -1);

        Date d1 = new Date(cal.getTimeInMillis());
        Date d2 = new Date(cal1.getTimeInMillis());

        return d1.getMonth() == d2.getMonth()
                && d1.getDate() == d2.getDate()
                && d1.getYear() == d2.getYear();
    }

    public static boolean isNight() {
        int hour = Calendar.getInstance().get(Calendar.HOUR_OF_DAY);
        return hour > 18 || hour < 7;
    }

    /**
     * Equivalent to Math.max(low, Math.min(high, amount));
     */
    public static float constrain(final float amount, final float low,
                                  final float high) {
        return amount < low ? low : amount > high ? high : amount;
    }

    /**
     * Equivalent to Math.max(low, Math.min(high, amount));
     */
    public static int constrain(final int amount, final int low, final int high) {
        return amount < low ? low : amount > high ? high : amount;
    }

    public static String formatNewsDate(String inDate) {
        try {
            long now = new Date().getTime();
            long inDateLong = Date.parse(inDate);
            long diffMin = ((now - inDateLong) / 1000) / 60;
            if (diffMin < 15)
                return "тукушто објавено";
            if (diffMin < 45)
                return String.format("пред %s мин.", diffMin);
            if (diffMin < 120)
                return "пред 1 час";
            if (diffMin < 12 * 60)
                return String.format("пред %s часа", diffMin / 60);
            if (isYesterday(inDateLong))
                return String.format("вчера во %s", new SimpleDateFormat("HH:mm").format(new Date(inDateLong)));
            return new SimpleDateFormat("dd.MM.yyyy во H:m").format(new Date(inDateLong));
        } catch (Exception e) {
            Log.e(LOG, "Error parsing input date: " + inDate, e);
        }
        return inDate;
    }
}
