package mk.tmarkovski.android.glasnik.activity;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.View;
import android.widget.*;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.currency.CurrencyModel;
import mk.tmarkovski.android.glasnik.currency.ExchangeRateDatabase;

import java.io.IOException;
import java.text.DecimalFormat;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 12.2.12
 * Time: 17:42
 * To change this template use File | Settings | File Templates.
 */
public class CurrencyActivity extends Activity implements AppConstants, View.OnFocusChangeListener {
    private List<CurrencyModel> mRates;
    private CurrencyModel mModel;

    private ImageView mLeftImage;
    private ImageView mRightImage;

    private Spinner mSpinnerLeft;
    private Spinner mSpinnerRight;

    private CurrencyModel mLeftCurrency;
    private CurrencyModel mRightCurrency;

    private EditText mLeftEdit;
    private EditText mRightEdit;

    private boolean mSuppressEventsLeft;
    private boolean mSuppressEventsRight;

    private BroadcastReceiver mUpdateReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            if (ACTION_CURRENCY_UPDATE.equals(intent.getAction())) {
                loadRates();
            }
        }
    };

    private void loadRates() {
        ExchangeRateDatabase db = new ExchangeRateDatabase(this);
        mRates = db.get();
        db.close();

        ((ListView) findViewById(R.id.ratesListView)).setAdapter(new CurrencyAdapter(this, mRates.toArray(new CurrencyModel[0])));
        mRates.add(0, mModel);

        ArrayAdapter<CharSequence> adapter = new ArrayAdapter<CharSequence>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        for (CurrencyModel model : mRates)
            adapter.add(model.getCurrencyName());
        mSpinnerLeft.setAdapter(adapter);
        mSpinnerLeft.setSelection(0);

        ArrayAdapter<CharSequence> adapter2 = new ArrayAdapter<CharSequence>(this, android.R.layout.simple_spinner_item);
        adapter2.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        for (CurrencyModel model : mRates)
            adapter2.add(model.getCurrencyName());
        mSpinnerRight.setAdapter(adapter2);
        mSpinnerRight.setSelection(adapter2.getCount() > 1 ? 1 : 0);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        registerReceiver(mUpdateReceiver, new IntentFilter(ACTION_CURRENCY_UPDATE));

        mModel = new CurrencyModel();
        mModel.setCurrencyName("MKD");
        mModel.setRate(1.0f);

        setContentView(R.layout.activity_currency);

        findViewById(R.id.currToggleCalc).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                view.setVisibility(View.GONE);
                findViewById(R.id.currCalcContainer).setVisibility(View.VISIBLE);

                Toast.makeText(getApplicationContext(), "Допри на знамето за промена на валута", Toast.LENGTH_SHORT).show();
            }
        });

        mSpinnerLeft = (Spinner) findViewById(R.id.spinner1);
        mSpinnerRight = (Spinner) findViewById(R.id.spinner2);
        mSpinnerLeft.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onNothingSelected(AdapterView<?> adapterView) {
            }

            @Override
            public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                try {
                    mLeftCurrency = mRates.get(i);

                    String flag = adapterView.getItemAtPosition(i).toString().toLowerCase();
                    mLeftImage.setImageBitmap(BitmapFactory.decodeStream(getApplicationContext().getResources().getAssets().open("flag_" + flag + ".png")));
                } catch (IOException e) {
                    Log.e(LOG, "Couldn't load image resource", e);
                }
                mSuppressEventsRight = true;
                calculate(mLeftEdit, mRightEdit, mLeftCurrency, mRightCurrency);
                mSuppressEventsRight = false;
            }
        });
        mSpinnerRight.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            public void onNothingSelected(AdapterView<?> adapterView) {
            }

            @Override
            public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                try {
                    mRightCurrency = mRates.get(i);

                    String flag = adapterView.getItemAtPosition(i).toString().toLowerCase();
                    mRightImage.setImageBitmap(BitmapFactory.decodeStream(getApplicationContext().getResources().getAssets().open("flag_" + flag + ".png")));
                } catch (IOException e) {
                    Log.e(LOG, "Couldn't load image resource", e);
                }
                mSuppressEventsLeft = true;
                calculate(mRightEdit, mLeftEdit, mRightCurrency, mLeftCurrency);
                mSuppressEventsLeft = false;
            }
        });

        mLeftImage = (ImageView) findViewById(R.id.calcImage1);
        mRightImage = (ImageView) findViewById(R.id.calcImage2);
        mLeftImage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                mSpinnerLeft.performClick();
            }
        });
        mRightImage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                mSpinnerRight.performClick();
            }
        });

        mLeftEdit = (EditText) findViewById(R.id.calcEdit1);
        mRightEdit = (EditText) findViewById(R.id.calcEdit2);

        mLeftEdit.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {
            }

            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {
                if (mSuppressEventsLeft)
                    return;
                mSuppressEventsRight = true;
                calculate(mLeftEdit, mRightEdit, mLeftCurrency, mRightCurrency);
                mSuppressEventsRight = false;
            }

            @Override
            public void afterTextChanged(Editable editable) {
            }
        });
        mRightEdit.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {

            }

            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {
                if (mSuppressEventsRight)
                    return;
                mSuppressEventsLeft = true;
                calculate(mRightEdit, mLeftEdit, mRightCurrency, mLeftCurrency);
                mSuppressEventsLeft = false;
            }

            @Override
            public void afterTextChanged(Editable editable) {

            }
        });

        mLeftEdit.setOnFocusChangeListener(this);
        mRightEdit.setOnFocusChangeListener(this);

        loadRates();
    }

    private void calculate(EditText pInput, EditText pOutput, CurrencyModel pInputCurrency, CurrencyModel pOutputCurrency) {
        try {
            float x = Float.parseFloat(pInput.getText().toString());
            float y = (x * pInputCurrency.getRate()) / pOutputCurrency.getRate();
            pOutput.setText(new DecimalFormat("#0.##").format(y));
        } catch (Exception e) {
        }
    }

    @Override
    public void onFocusChange(View view, boolean b) {
        if (b && view instanceof EditText) {
            ((EditText) view).selectAll();
        }
    }
}
