package mk.tmarkovski.android.glasnik.activity;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.*;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.Utils;
import mk.tmarkovski.android.glasnik.feed.Article;

import java.io.FileInputStream;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 31.1.12
 * Time: 01:23
 * To change this template use File | Settings | File Templates.
 */
public class FeedAdapter extends BaseAdapter implements Filterable, AppConstants {
    private Context context;
    private List<Article> articles;

    private boolean mShowImages;

    private LayoutInflater mInflater;

    public FeedAdapter(Context context, List<Article> articles) {
        this.context = context;
        this.articles = articles;

        mInflater = LayoutInflater.from(context);
        mShowImages = PreferenceManager.getDefaultSharedPreferences(context).getBoolean(PREF_DOWNLOAD_IMAGES, false);
    }

    public int getCount() {
        return articles.size();
    }

    public Object getItem(int i) {
        return articles.get(i);
    }

    public long getItemId(int i) {
        return 0;
    }

    public View getView(int i, View view, ViewGroup viewGroup) {
        ViewHolder holder;

        if (view == null) {
            view = mInflater.inflate(R.layout.list_entry_news, null);

            holder = new ViewHolder();
            holder.textTitle = (TextView) view.findViewById(R.id.textTitle);
            holder.textDescription = (TextView) view.findViewById(R.id.textDescription);
            holder.textPublished = (TextView) view.findViewById(R.id.textPublished);
            holder.imageView = (ImageView) view.findViewById(R.id.imageArticle);
            holder.imageContainer = view.findViewById(R.id.imageArticleContainer);

            final boolean isMedia = articles.get(i).getMediaUrl() != null;
            final String url = isMedia ? articles.get(i).getMediaUrl() : articles.get(i).getUrl();
            final String title = articles.get(i).getTitle();
            view.setOnClickListener(new View.OnClickListener() {
                public void onClick(View view) {
                    Intent intent = new Intent(context, isMedia ? VideoActivity.class : ArticleActivity.class);
                    intent.putExtra(URL_TAG_EXTRA, url)
                            .putExtra(TITLE_TAG_EXTRA, title);
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                    context.startActivity(intent);
                }
            });

            view.setTag(holder);
        } else {
            holder = (ViewHolder) view.getTag();
        }

        holder.textTitle.setText(articles.get(i).getTitle());
        holder.textDescription.setText(articles.get(i).getDescription());
        holder.textPublished.setText(Utils.formatNewsDate(articles.get(i).getPublished()));

        if (mShowImages) {
            String filename = "feed_" + articles.get(i).getFeedCode() + "_" + articles.get(i).getId().toString();
            try {
                FileInputStream inputStream = view.getContext().openFileInput(filename);
                Bitmap bitmap = BitmapFactory.decodeStream(inputStream);
                holder.imageView.setImageBitmap(bitmap);
                inputStream.close();
            } catch (Exception e) {
                Log.e(LOG, "Error reading image " + filename, e);
                holder.imageContainer.setVisibility(View.GONE);
            }
        } else
            holder.imageContainer.setVisibility(View.GONE);

        return view;
    }


    public Filter getFilter() {
        return null;
    }

    class ViewHolder {
        TextView textTitle;
        ImageView imageView;
        TextView textDescription;
        TextView textPublished;
        View imageContainer;
    }
}
