package mk.tmarkovski.android.glasnik.activity;

import android.app.PendingIntent;
import android.app.TabActivity;
import android.content.*;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.*;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TabHost;

import android.widget.TextView;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.Utils;
import mk.tmarkovski.android.glasnik.feed.DatabaseManager;
import mk.tmarkovski.android.glasnik.updates.IntentManager;
import mk.tmarkovski.android.glasnik.updates.UpdateIntentService;

public class MainActivity extends TabActivity implements AppConstants, TabHost.OnTabChangeListener {
    private TabHost mTabHost;
    private int mCurrentTab;

    private BroadcastReceiver mUpdateReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals(ACTION_FEED_UPDATE_PROGRESS)) {
                int progress = intent.getIntExtra(PROGRESS_EXTRA, 0);
                findViewById(R.id.progressBarMain).setVisibility(progress == 100 ? View.INVISIBLE : View.VISIBLE);
                ((ProgressBar) findViewById(R.id.progressBarMain)).setProgress(progress);
                ((TextView) findViewById(R.id.mainUpdatedText)).setText(progress == 100 ? "Последно ажурирано " + Utils.getWidgetDateFormat(getApplicationContext(),
                        PreferenceManager.getDefaultSharedPreferences(getApplicationContext()).getLong(PREF_LAST_GLOBAL_UPDATE, 0)) : String.format("%s%%", progress));

                if (progress == 100 && mTabHost.getTabWidget().getTabCount() == 0)
                    loadTabs();
            }
        }
    };

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        registerReceiver(mUpdateReceiver, new IntentFilter(ACTION_FEED_UPDATE_PROGRESS));
        requestWindowFeature(Window.FEATURE_NO_TITLE);

        setContentView(R.layout.activity_main);

        ((TextView) findViewById(R.id.mainUpdatedText)).setText("Последно ажурирано " + Utils.getWidgetDateFormat(this,
                PreferenceManager.getDefaultSharedPreferences(this).getLong(PREF_LAST_GLOBAL_UPDATE, 0)));
        DatabaseManager db = new DatabaseManager(this);
        this.mTabHost = getTabHost();
        if (db.getFeeds(true).size() > 0){
            loadTabs();
        }
        db.close();

        mTabHost.setOnTabChangedListener(this);

        if (UpdateIntentService.isUpdateOverdue(this))
            manualUpdate();
    }

    private void loadTabs() {
        mTabHost.addTab(mTabHost.newTabSpec("news")
                .setIndicator(createTabView(mTabHost.getContext(), "вести", R.drawable.news_tab))
                .setContent(new Intent(this, NewsActivity.class)));

        mTabHost.addTab(mTabHost.newTabSpec("weather")
                .setIndicator(createTabView(mTabHost.getContext(), "време", R.drawable.weather_tab))
                .setContent(new Intent(this, WeatherActivity.class)));

        mTabHost.addTab(mTabHost.newTabSpec("currency")
                .setIndicator(createTabView(mTabHost.getContext(), "курс", R.drawable.currency_tab))
                .setContent(new Intent(this, CurrencyActivity.class)));
    }

    private View createTabView(Context context, String tag, int layoutId) {
        View view = LayoutInflater.from(context).inflate(R.layout.tabs_bg, null);
        ImageView iv = (ImageView) view;
        iv.setImageResource(layoutId);
        return view;
    }

    private void manualUpdate() {
        PendingIntent pendingIntent = IntentManager.getPendingIntent(this);
        Intent intent = IntentManager.getIntent(this);
        intent.putExtra(FORCE_UPDATE_EXTRA, true);

        try {
            pendingIntent.send(this, 0, intent);
        } catch (PendingIntent.CanceledException e) {
            Log.e(LOG, "Error starting manual update.", e);
            setProgressBarIndeterminateVisibility(false);
        }
    }

    @Override
    public void onTabChanged(String s) {
        int newTab = mTabHost.getCurrentTab();

        Animation inAnimation;
        if (newTab > mCurrentTab) {
            inAnimation = AnimationUtils.loadAnimation(this, R.anim.slide_in_right);

        } else {
            inAnimation = AnimationUtils.loadAnimation(this, R.anim.slide_in_left);
        }
        mTabHost.getTabContentView().setAnimation(inAnimation);
        inAnimation.start();

        mCurrentTab = newTab;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        menu.add("Што е најново?").setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            public boolean onMenuItemClick(MenuItem menuItem) {
                manualUpdate();
                return false;
            }
        });
        menu.add("Подесувања").setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            public boolean onMenuItemClick(MenuItem menuItem) {
                startActivity(new Intent(MainActivity.this, SettingsActivity.class));
                return false;
            }
        });
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        unregisterReceiver(mUpdateReceiver);
    }
}
