package mk.tmarkovski.android.glasnik.activity;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.view.PagerAdapter;
import android.support.v4.view.ViewPager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.feed.Article;
import mk.tmarkovski.android.glasnik.feed.DatabaseManager;
import mk.tmarkovski.android.glasnik.feed.Feed;

import java.util.List;
import java.util.zip.Inflater;

import static android.graphics.BitmapFactory.decodeResource;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 8.3.12
 * Time: 00:15
 * To change this template use File | Settings | File Templates.
 */
public class NewsActivity extends Activity implements AppConstants {
    private LayoutInflater mInflater;
    private List<Feed> feeds;

    private BroadcastReceiver mUpdateReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals(ACTION_FEED_UPDATE_PROGRESS)) {
                int progress = intent.getIntExtra(PROGRESS_EXTRA, 0);
                if (progress == 100)
                    load();
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        registerReceiver(mUpdateReceiver, new IntentFilter(ACTION_FEED_UPDATE_PROGRESS));

        DatabaseManager db = new DatabaseManager(this);
        feeds = db.getFeeds(true);
        db.close();
        this.mInflater = LayoutInflater.from(this);


        setContentView(R.layout.activity_news_fragment);
        if (feeds.size() > 0)
            load();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        unregisterReceiver(mUpdateReceiver);
    }

    private void load() {
        ViewPager viewPager = ((ViewPager) findViewById(R.id.newsViewPager));
        viewPager.setPageMargin(10);
        viewPager.setAdapter(new PagerAdapter() {
            @Override
            public int getCount() {
                return feeds.size();
            }

            @Override
            public Object instantiateItem(ViewGroup collection, int position) {

                DatabaseManager db = new DatabaseManager(getApplicationContext());
                final List<Article> articles = db.get(feeds.get(position));
                db.close();

                ListView listView = new ListView(getApplicationContext());
                listView.setDividerHeight(1);
                listView.setDivider(getResources().getDrawable(R.drawable.tab_divider));
                listView.setAdapter(new FeedAdapter(getApplicationContext(), articles));
                collection.addView(listView);

                return listView;
            }

            @Override
            public void destroyItem(ViewGroup collection, int position, Object view) {
                collection.removeView((View) view);
            }

            @Override
            public boolean isViewFromObject(View view, Object object) {
                return view == object;
            }

            @Override
            public CharSequence getPageTitle(int position) {
                return feeds.size() > 0 ? feeds.get(position).getDescription() : "";
            }
        });
    }
}
