package mk.tmarkovski.android.glasnik.currency;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: tomislav.markovski
 * Date: 2/24/12
 * Time: 4:40 PM
 * To change this template use File | Settings | File Templates.
 */
public class ExchangeRateDatabase {
    private static final String DATABASE_NAME = "exchange_rates";
    private Context mContext;
    private SQLiteDatabase mDb;

    public ExchangeRateDatabase(Context context) {
        this.mContext = context;

        this.mDb = this.mContext.openOrCreateDatabase(DATABASE_NAME, Context.MODE_PRIVATE, null);
        this.mDb.execSQL("CREATE TABLE IF NOT EXISTS rates (rate REAL, units INTEGER, currency_code INTEGER, currency_name TEXT, currency_name_mk TEXT, country_mk TEXT, valid_to TEXT)");
    }

    public ExchangeRateDatabase add(CurrencyModel currencyModel) {
        ContentValues values = new ContentValues();
        values.put("rate", currencyModel.getRate());
        values.put("units", currencyModel.getCurrencyUnits());
        values.put("currency_code", currencyModel.getCurrencyCode());
        values.put("currency_name", currencyModel.getCurrencyName());
        values.put("country_mk", currencyModel.getCountryName_mk());
        values.put("currency_name_mk", currencyModel.getCurrencyName_mk());
        this.mDb.insert("rates", null, values);
        return this;
    }

    public void close() {
        this.mDb.close();
    }

    public ExchangeRateDatabase clear() {
        this.mDb.delete("rates", null, null);
        return this;
    }

    public List<CurrencyModel> get() {
        List<CurrencyModel> result = new ArrayList<CurrencyModel>();
        Cursor cursor = this.mDb.query("rates", new String[]{"rate", "units", "currency_code", "currency_name", "country_mk", "valid_to", "currency_name_mk"},
                null, null, null, null, null);
        boolean hasData = cursor.moveToFirst();
        while (hasData) {
            CurrencyModel model = new CurrencyModel();
            model.setRate(cursor.getFloat(0));
            model.setCurrencyUnits(cursor.getDouble(1));
            model.setCurrencyCode(cursor.getDouble(2));
            model.setCurrencyName(cursor.getString(3));
            model.setCountryName_mk(cursor.getString(4));
            //model.setDate(new Date(cursor.getString(5)));
            model.setCurrencyName_mk(cursor.getString(6));
            result.add(model);
            hasData = cursor.moveToNext();
        }
        cursor.close();
        return result;
    }

    public ExchangeRateDatabase addAll(List<CurrencyModel> models) {
        for (CurrencyModel model : models){
            add(model);
        }
        return this;
    }
}
