package mk.tmarkovski.android.glasnik.feed;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import mk.tmarkovski.android.glasnik.AppConstants;

import java.net.URL;
import java.sql.Date;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 30.1.12
 * Time: 20:13
 * To change this template use File | Settings | File Templates.
 */
public class DatabaseManager implements AppConstants {
    private static final String CREATE_TABLE_FEEDS = "create table if not exists feeds (feed_code TEXT primary key, "
            + "title text not null, url text not null, enabled integer not null, updated integer);";

    private static final String CREATE_TABLE_ARTICLES = "create table if not exists articles (article_id integer primary key autoincrement, "
            + "feed_code TEXT not null, title text not null, url text not null, category text, description text, image text, published text, media_url text);";

    private static final String FEEDS_TABLE = "feeds";
    private static final String ARTICLES_TABLE = "articles";
    private static final String DATABASE_NAME = "rssreader";

    private SQLiteDatabase db;
    private Context mContext;

    public DatabaseManager(Context context) {
        this.mContext = context;
        try {
            db = context.openOrCreateDatabase(DATABASE_NAME, Context.MODE_PRIVATE, null);
            db.execSQL(CREATE_TABLE_FEEDS);
            db.execSQL(CREATE_TABLE_ARTICLES);

        } catch (Exception e) {
            Log.e(LOG, "Error opening or creating database.", e);
        }
    }

    public void close() {
        db.close();
    }

    public void add(Feed feed) {
        try {
            ContentValues values = new ContentValues();
            values.put("feed_code", feed.getCode());
            values.put("title", feed.getDescription());
            values.put("url", feed.getUrl().toString());
            values.put("enabled", 1);
            values.put("updated", 0);
            db.insert(FEEDS_TABLE, null, values);
        } catch (Exception e) {
            Log.e(LOG, e.toString());
        }
    }

    public void add(Article article) {
        try {
            ContentValues values = new ContentValues();
            values.put("feed_code", article.getFeedCode());
            values.put("title", article.getTitle());
            values.put("url", article.getUrl());
            values.put("category", article.getCategory());
            values.put("description", article.getDescription());
            values.put("image", article.getImage());
            values.put("published", article.getPublished());
            values.put("media_url", article.getMediaUrl());
            db.insert(ARTICLES_TABLE, null, values);
        } catch (Exception e) {
            Log.e(LOG, e.toString());
        }
    }

    public void delete(Feed pFeed) {
        try {
            db.delete(ARTICLES_TABLE, "feed_code='" + pFeed.getCode() + "'", null);
        } catch (Exception e) {
            Log.e(LOG, e.toString(), e);
        }
    }

    public List<Feed> getFeeds(String selection) {
        ArrayList<Feed> feeds = new ArrayList<Feed>();
        try {
            Cursor c = db.query(FEEDS_TABLE, new String[]{"feed_code", "title",
                    "url", "enabled", "updated"}, selection, null, null, null, "feed_code");

            int numRows = c.getCount();
            c.moveToFirst();
            for (int i = 0; i < numRows; ++i) {
                Feed feed = new Feed(c.getString(0), new URL(c.getString(2)), c.getString(1));
                feed.setEnabled(c.getInt(3) == 0 ? false : true);
                feed.setUpdated(new Date(c.getLong(4)));
                feeds.add(feed);
                c.moveToNext();
            }
            c.close();
        } catch (Exception e) {
            Log.e(LOG, e.toString());
        }
        return feeds;
    }

    public List<Feed> getFeeds(boolean enabledOnly) {
        return getFeeds(enabledOnly ? "enabled=1" : null);
    }

    public List<Article> getArticles(String selection) {
        ArrayList<Article> articles = new ArrayList<Article>();
        try {
            Cursor c = db.query(ARTICLES_TABLE, new String[]{"article_id",
                    "feed_code", "title", "url", "category", "description", "image", "published", "media_url"},
                    selection, null, null, null, "published DESC");

            int numRows = c.getCount();
            c.moveToFirst();
            for (int i = 0; i < numRows; ++i) {
                Article article = new Article();
                article.setId(c.getLong(0));
                article.setFeedCode(c.getString(1));
                article.setTitle(c.getString(2));
                article.setUrl(c.getString(3));
                article.setCategory(c.getString(4));
                article.setDescription(c.getString(5));
                article.setImage(c.getString(6));
                article.setPublished(c.getString(7));
                article.setMediaUrl(c.getString(8));
                articles.add(article);
                c.moveToNext();
            }
            c.close();
        } catch (Exception e) {
            Log.e(LOG, e.toString());
        }
        return articles;
    }

    public List<Article> get(Feed pFeed) {
        return getArticles(String.format("feed_code='%s'", pFeed.getCode()));
    }

    public void update(Feed pFeed) {
        ContentValues values = new ContentValues();
        values.put("enabled", pFeed.getEnabled() ? 1 : 0);
        values.put("updated", pFeed.getUpdated().getTime());
        db.update(FEEDS_TABLE, values, String.format("feed_code='%s'", pFeed.getCode()), null);
    }

    public void generate() {

        for (String key : mDefaultFeedCollection.keySet()) {
            try {
                FeedDefinition definition = mDefaultFeedCollection.get(key);
                Feed feed = new Feed(key, new URL(definition.getUrl()), definition.getDescription());
                feed.setEnabled(true);
                feed.setUpdated(new Date(0));
                add(feed);
            } catch (Exception e) {
                Log.e(LOG, "Could not add feed: " + key, e);
            }
        }
    }
}
