package mk.tmarkovski.android.glasnik.feed;

import android.content.Context;
import android.preference.PreferenceManager;
import android.util.Log;
import mk.tmarkovski.android.glasnik.AppConstants;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 30.1.12
 * Time: 21:16
 * To change this template use File | Settings | File Templates.
 */
public class FeedHandler implements AppConstants {

    private List<Article> articles;

    public FeedHandler(Feed feed, Context context) {

        final int maxFeeds = PreferenceManager.getDefaultSharedPreferences(context).getInt(PREF_MAX_FEED_COUNT, 5);
        final IFeedFormatter formatter = mDefaultFeedCollection.get(feed.getCode()).getFormatter();

        articles = new ArrayList<Article>();

        try {
            Document document = Jsoup.parse(feed.getUrl().openStream(),
                    mDefaultFeedCollection.get(feed.getCode()).getEncoding(),
                    feed.getUrl().toString());
            List<Element> elements = document.getElementsByTag("item");
            int count = 0;
            for (Element element : elements) {
                if (count >= maxFeeds)
                    break;
                try {
                    Article article = new Article();
                    article.setDescription(element.getElementsByTag("description").text());
                    article.setTitle(element.getElementsByTag("title").text());
                    article.setUrl(element.getElementsByTag("link").text());
                    if (element.getElementsByTag("published").size() > 0)
                        article.setPublished(element.getElementsByTag("published").text());
                    if (element.getElementsByTag("pubdate").size() > 0)
                        article.setPublished(element.getElementsByTag("pubdate").text());
                    article.setFeedCode(feed.getCode());

                    if (formatter != null)
                        formatter.formatArticle(element, article);

                    articles.add(article);

                } catch (Exception e) {
                    Log.e(LOG, "Error parsing item: " + count, e);
                } finally {
                    count++;
                }
            }

        } catch (Exception e) {
            Log.e(LOG, "Error parsing document: " + feed.getCode(), e);
        }
    }

    public List<Article> get() {
        return articles;
    }
}
