package mk.tmarkovski.android.glasnik.feed;

import android.content.Context;
import android.content.Intent;
import android.preference.PreferenceManager;
import android.util.Log;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.updates.ProgressRunnable;
import mk.tmarkovski.android.glasnik.updates.UpdateIntentService;

import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.*;

public class FeedUpdater implements AppConstants {

    private static boolean isUpdating = false;

    public static void update(Context context, ProgressRunnable mProgress) {
        if (isUpdating)
            return;

        DatabaseManager db = new DatabaseManager(context);

        if (db.getFeeds(false).size() == 0)
            db.generate();

        for (Feed feed : db.getFeeds(true)) {
            List<Article> articles;

            // fetch all articles for feed
            articles = new FeedHandler(feed, context)
                    .get();
            Log.d(LOG, "Fetched " + articles.size() + " for feed " + feed.getCode());
            if (articles != null && articles.size() == 0)
                continue;

            feed.setUpdated(new Date());
            db.update(feed);
            db.delete(feed);
            // remove all images for current feed
            for (String file : context.fileList())
                if (file.startsWith("feed_" + feed.getCode() + "_"))
                    context.deleteFile(file);

            for (Article article : articles) {
                db.add(article);
            }

            if (mProgress != null)
                mProgress.progress(1);

            if (PreferenceManager.getDefaultSharedPreferences(context).getBoolean(PREF_DOWNLOAD_IMAGES, false)) {
                Log.d(LOG, "Images enabled. Fetching images for feed " + feed.getCode());
                // fetch new images
                for (Article article : db.get(feed)) {
                    String filename = String.format("feed_%s_%s", article.getFeedCode(), article.getId());
                    try {
                        InputStream inputStream = new URL(article.getImage()).openStream();
                        if (inputStream != null) {
                            FileOutputStream fos = context.openFileOutput(filename, Context.MODE_PRIVATE);
                            int current;
                            while ((current = inputStream.read()) != -1)
                                fos.write((byte) current);
                            fos.close();
                            inputStream.close();
                        }
                    } catch (Exception e) {
                        Log.e(LOG, "Error fetching image: " + article.getImage(), e);
                    }
                }
                if (mProgress != null)
                    mProgress.progress(1);
            }


        }
        db.close();

        // notify receivers that update ended
        context.sendBroadcast(new Intent(ACTION_FEED_UPDATE));

        isUpdating = false;
    }

    public static String getWidgetFeedCode(Context context) {
        String widgetFeedCode = PreferenceManager.getDefaultSharedPreferences(context).getString(PREF_WIDGET_FEED_CODE, "");
        if (mDefaultFeedCollection.containsKey(widgetFeedCode)) {
            return widgetFeedCode;
        } else {
            for (String key : mDefaultFeedCollection.keySet())
                return key;
        }
        return null;
    }
}
