package mk.tmarkovski.android.glasnik.updates;

import android.app.IntentService;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.ConnectivityManager;
import android.os.PowerManager;
import android.preference.PreferenceManager;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.currency.CurrencyUpdater;
import mk.tmarkovski.android.glasnik.feed.DatabaseManager;
import mk.tmarkovski.android.glasnik.feed.FeedUpdater;
import mk.tmarkovski.android.glasnik.weather.WeatherUpdater;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 6.2.12
 * Time: 20:05
 * To change this template use File | Settings | File Templates.
 */
public class UpdateIntentService extends IntentService implements AppConstants {

    private static boolean mUpdating = false;
    private int mStep;

    public UpdateIntentService() {
        super("UpdateServiceIntent");
    }

    @Override
    protected void onHandleIntent(Intent intent) {

        if (mUpdating)
            return;
        mUpdating = true;
        if (screenIsOn()
                && (isUpdateOverdue(this) || intent.getBooleanExtra(FORCE_UPDATE_EXTRA, false))) {

            // cancel the alarm to prevent ticks in case update hasn't finished
            AlarmHandler.cancel(this);

            PreferenceManager.getDefaultSharedPreferences(this).edit()
                    .putLong(PREF_LAST_GLOBAL_UPDATE, new Date().getTime()).commit();

            this.mStep = 100 / ((mDefaultFeedCollection.size() * (PreferenceManager.getDefaultSharedPreferences(this).getBoolean(PREF_DOWNLOAD_IMAGES, false) ? 2 : 1)) + 2);
            this.mProgress = new ProgressRunnable(this);
            this.mProgress.setStep(mStep);

            this.mProgress.start();
            WeatherUpdater.update(this);

            this.mProgress.progress(1);
            FeedUpdater.update(this, this.mProgress);

            CurrencyUpdater.update(this);
            this.mProgress.finish();

            // restart alarm
            AlarmHandler.updateAlarm(this);
        }

        mUpdating = false;
    }

    private ProgressRunnable mProgress;

    public static boolean isUpdateOverdue(Context context) {
        SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(context);
        Long last_update = preferences.getLong(PREF_LAST_GLOBAL_UPDATE, 0);
        Long diff = ((new Date().getTime() - last_update) / 1000) / 60;

        int selectedInterval = Integer.valueOf(preferences.getString(PREF_UPDATE_INTERVAL, "60"));
        return diff > selectedInterval;
    }

    private boolean screenIsOn() {
        PowerManager pm = (PowerManager) getSystemService(Context.POWER_SERVICE);
        return pm.isScreenOn();
    }
}
