package mk.tmarkovski.android.glasnik.weather;

import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.Utils;

import java.util.HashMap;

/**
 * Useful Utility in working with temperatures. (conversions).
 */
public class WeatherUtils {

    public static int fahrenheitToCelsius(int tFahrenheit) {
        return (int) ((5.0f / 9.0f) * (tFahrenheit - 32));
    }

    public static int celsiusToFahrenheit(int tCelsius) {
        return (int) ((9.0f / 5.0f) * tCelsius + 32);
    }

    public static int conditionToImage(String condition, boolean ignoreTime) {
        String image = "w_" + condition.toLowerCase().replace(" ", "_");
        image = image + (!Utils.isNight() || ignoreTime ? "_d" : "_n");
        return conditionImageMap.containsKey(image) ? conditionImageMap.get(image) : R.drawable.w_na;
    }

    public static CharSequence conditionToLocalString(String condition) {
        return conditionStringMap.containsKey(condition.toLowerCase())
                ? conditionStringMap.get(condition.toLowerCase()).toString()
                : condition;
    }

    public static final HashMap<String, String> conditionStringMap = new HashMap<String, String>() {
        {
            put("overcast", "Заоблачено");
            put("cloudy", "Облачно");
            put("chance of snow", "Можност за снег");
            put("chance of rain", "Можност за дожд");
            put("mostly sunny", "Претежно сончево");
            put("partly sunny", "Делумно сончево");
            put("clear", "Ведро");
            put("partly cloudy", "Делумно облачно");
            put("mostly cloudy", "Претежно облачно");
            put("rain", "Дожд");
            put("fog", "Магла");
            put("light snow", "Вејавица");
        }
    };

    public static final HashMap<String, Integer> conditionImageMap = new HashMap<String, Integer>() {
        {
            put("w_overcast_n", R.drawable.w_cloudy);
            put("w_overcast_d", R.drawable.w_cloudy);
            put("w_cloudy_n", R.drawable.w_cloudy);
            put("w_cloudy_d", R.drawable.w_cloudy);
            put("w_mostly_sunny_d", R.drawable.w_mostly_sunny_d);
            put("w_partly_sunny_d", R.drawable.w_partly_sunny_d);
            put("w_clear_d", R.drawable.w_sunny_d);
            put("w_clear_n", R.drawable.w_sunny_n);
            put("w_chance_of_snow_d", R.drawable.w_chance_of_snow_d);
            put("w_chance_of_rain_d", R.drawable.w_chance_of_rain_d);
            put("w_chance_of_thunderstorm_d", R.drawable.w_chance_of_thunderstorm_d);
            put("w_chance_of_thunderstorm_n", R.drawable.w_chance_of_thunderstorm_n);
            put("w_partly_cloudy_n", R.drawable.w_partly_cloudy_n);
            put("w_partly_cloudy_d", R.drawable.w_mostly_sunny_d);
            put("w_mostly_cloudy_d", R.drawable.w_partly_sunny_d);
            put("w_mostly_cloudy_n", R.drawable.w_mostly_cloudy_n);
            put("w_rain_d", R.drawable.w_rain);
            put("w_rain_n", R.drawable.w_rain);
            put("w_storm_d", R.drawable.w_storm);
            put("w_storm_n", R.drawable.w_storm);
            put("w_thunderstorm_d", R.drawable.w_thunderstorn);
            put("w_thunderstorm_n", R.drawable.w_thunderstorn);
            put("w_fog_d", R.drawable.w_fog);
            put("w_fog_n", R.drawable.w_fog);
            put("w_light_snow_d", R.drawable.w_light_snow);
            put("w_light_snow_n", R.drawable.w_light_snow);
        }
        /*
            sunny
            mostly sunny
            partly cloudy
            mostly cloudy
            chance of storm
            rain
            chance of rain
            chance of snow
            cloudy
            mist
            storm
            thunderstorm
            chance of tstorm
            sleet
            snow
            icy
            dust
            fog
            smoke
            haze
            flurries
         */
    };
}
