package mk.tmarkovski.android.glasnik.widget;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.View;
import android.widget.RemoteViews;
import mk.tmarkovski.android.glasnik.AppConstants;
import mk.tmarkovski.android.glasnik.R;
import mk.tmarkovski.android.glasnik.Utils;
import mk.tmarkovski.android.glasnik.activity.MainActivity;
import mk.tmarkovski.android.glasnik.feed.Article;
import mk.tmarkovski.android.glasnik.feed.DatabaseManager;
import mk.tmarkovski.android.glasnik.feed.Feed;
import mk.tmarkovski.android.glasnik.updates.AlarmHandler;
import mk.tmarkovski.android.glasnik.weather.LocationFinder;
import mk.tmarkovski.android.glasnik.weather.WeatherSet;
import mk.tmarkovski.android.glasnik.weather.WeatherUpdater;
import mk.tmarkovski.android.glasnik.weather.WeatherUtils;

/**
 * Created by IntelliJ IDEA.
 * User: Tome
 * Date: 2.2.12
 * Time: 02:20
 * To change this template use File | Settings | File Templates.
 */
public class WidgetProvider extends AppWidgetProvider implements AppConstants {

    @Override
    public void onDisabled(Context context) {
        super.onDisabled(context);

        PreferenceManager.getDefaultSharedPreferences(context)
                .edit().putInt("widget_id", -1)
                .commit();
    }

    @Override
    public void onReceive(Context context, Intent intent) {
        super.onReceive(context, intent);

        if (ACTION_FEED_UPDATE.equals(intent.getAction())) {
            WidgetProvider.updateFeeds(context);
        }
        if (ACTION_WEATHER_UPDATE.equals(intent.getAction())) {
            WidgetProvider.updateWeather(context);
        }
    }

    @Override
    public void onUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) {
        super.onUpdate(context, appWidgetManager, appWidgetIds);

        PreferenceManager.getDefaultSharedPreferences(context)
                .edit().putInt("widget_id", appWidgetIds[0])
                .commit();

        AlarmHandler.updateAlarm(context);
        WidgetProvider.updateFeeds(context);
        WidgetProvider.updateWeather(context);
    }

    public static void updateWeather(Context context) {
        int appWidgetId = PreferenceManager.getDefaultSharedPreferences(context).getInt("widget_id", -1);

        if (appWidgetId > -1) {
            RemoteViews widget = getWidget(context);
            if (Utils.isNight()) {
                widget.setViewVisibility(R.id.widgetWeatherBackgroundNight, View.VISIBLE);
                widget.setViewVisibility(R.id.widgetWeatherBackgroundDay, View.INVISIBLE);
            } else {
                widget.setViewVisibility(R.id.widgetWeatherBackgroundNight, View.INVISIBLE);
                widget.setViewVisibility(R.id.widgetWeatherBackgroundDay, View.VISIBLE);
            }

            WeatherSet weatherSet = WeatherUpdater.getWeather(context);
            widget.setImageViewResource(R.id.widgetWeatherIcon, WeatherUtils.conditionToImage(weatherSet.getWeatherCurrentCondition().getCondition(), false));
            widget.setTextViewText(R.id.widgetWeatherCity, new LocationFinder().getCityNameLocal(context));
            widget.setTextViewText(R.id.widgetWeatherCondition, WeatherUtils.conditionToLocalString(weatherSet.getWeatherCurrentCondition().getCondition()));
            widget.setTextViewText(R.id.widgetWeatherTemp, weatherSet.getWeatherCurrentCondition().getTempCelcius().toString() + "°C");
            
            getManager(context).updateAppWidget(appWidgetId, widget);
        }
    }

    public static void updateFeeds(Context context) {

        int appWidgetId = PreferenceManager.getDefaultSharedPreferences(context).getInt("widget_id", -1);
        final boolean showImages = PreferenceManager.getDefaultSharedPreferences(context).getBoolean(PREF_DOWNLOAD_IMAGES, false);

        if (appWidgetId > -1) {
            // Update widget data
            RemoteViews widget = getWidget(context);
            PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, new Intent(context, MainActivity.class), 0);
            widget.setOnClickPendingIntent(R.id.widget_layout, pendingIntent);
            widget.removeAllViews(R.id.widgetFlipper);
            getManager(context).updateAppWidget(appWidgetId, widget);

            DatabaseManager db = new DatabaseManager(context);

            long updated = PreferenceManager.getDefaultSharedPreferences(context).getLong(PREF_LAST_GLOBAL_UPDATE, 0);
            for (Feed feed : db.getFeeds(true)) {
                widget = getWidget(context);
                int cnt = 0;
                for (Article article : db.get(feed)) {
                    if (cnt >= WIDGET_NEWS_COUNT_PER_CATEGORY)
                        break;

                    RemoteViews entry = new RemoteViews(context.getPackageName(), R.layout.widget_slide);

                    entry.setTextViewText(R.id.widget_update, Utils.getWidgetDateFormat(context, updated));
                    entry.setTextViewText(R.id.widget_title, article.getTitle());
                    entry.setTextViewText(R.id.widget_feed_category, feed.getDescription());
                    cnt++;
                    if (showImages) {
                        try {
                            String filename = String.format("feed_%s_%s", feed.getCode(), article.getId());
                            Bitmap bitmap = BitmapFactory.decodeStream(context.openFileInput(filename));
                            if (bitmap != null) {
                                entry.setImageViewBitmap(R.id.widget_image, Utils.scaleBitmap(bitmap));
                            }
                        } catch (Exception e) {
                            Log.e(LOG, "Error adding widget slide for file: " + cnt, e);
                        }
                    }
                    widget.addView(R.id.widgetFlipper, entry);
                }
                getManager(context).updateAppWidget(appWidgetId, widget);
            }
            db.close();
        }
    }

    public static RemoteViews getWidget(Context context) {
        return new RemoteViews(context.getPackageName(), R.layout.widget);
    }

    public static AppWidgetManager getManager(Context context) {
        return AppWidgetManager.getInstance(context);
    }
}
